#
# spec file for package python-tables
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname tables
Name:           python-%{modname}
Version:        3.2.0
Release:        3.16
Summary:        Hierarchical datasets for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://www.pytables.org/
Source0:        https://pypi.python.org/packages/source/t/tables/%{modname}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel >= 1.8.10
BuildRequires:  libbz2-devel
BuildRequires:  lzo-devel
BuildRequires:  python-Cython >= 0.13
BuildRequires:  python-blosc
BuildRequires:  python-devel >= 2.6
BuildRequires:  python-numexpr >= 2.0
BuildRequires:  python-numpy-devel >= 1.4.1
BuildRequires:  python-setuptools
Requires:       hdf5 >= 1.8.10
Requires:       python-blosc
Requires:       python-numexpr >= 2.0
Requires:       python-numpy >= 1.4.1
Recommends:     bzip2
Recommends:     lzo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
PyTables is a package for managing hierarchical datasets and
designed to efficently cope with extremely large amounts of
data. PyTables is built on top of the HDF5 library and the
NumPy package and features an object-oriented interface
that, combined with C-code generated from Pyrex sources,
makes of it a fast, yet extremely easy to use tool for
interactively save and retrieve large amounts of data.

%package doc
Summary:        Documentation for %{name}
Group:          Development/Languages/Python

%description doc
Documentation and help files for %{name}

%prep
%setup -q -n %{modname}-%{version}

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}%{python_sitearch}

%files
%defattr(-,root,root)
%doc ANNOUNCE.txt LICENSE.txt README.rst RELEASE_NOTES.txt THANKS
%{_bindir}/pt2to3
%{_bindir}/ptdump
%{_bindir}/ptrepack
%{_bindir}/pttree
%{python_sitearch}/%{modname}/
%{python_sitearch}/%{modname}-%{version}-py%{py_ver}.egg-info

%files doc
%defattr(-,root,root)
%doc doc/html

%changelog
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 3.2.0:
  Improvements
  * The nrowsinbuf is better computed now for EArray/CArray having
    a small chunkshape in the main dimension. Fixes #285.
  * PyTables should be installable very friendly via pip, including
    NumPy being installed automatically in the unlikely case it is
    not yet installed in the system. Thanks to Andrea Bedini.
  * setup.py has been largely simplified and now it requires
    setuptools. Although we think this is a good step, please keep
    us informed this is breaking some installation in a very bad
    manner.
  * setup.py now is able to used pkg-config, if available, to
    locate required libraries (hdf5, bzip2, etc.). The use of
    pkg-config can be controlled via setup.py command line flags or
    via environment variables. Please refer to the installation
    guide (in the User Manual) for details. Closes gh-442.
  * It is now possible to create a new node whose parent is a
    softlink to another group (see gh-422). Thanks to Alistair
    Muldal.
  * link.SoftLink objects no longer need to be explicitly
    dereferenced. Methods and attributes of the linked object are
    now automatically accessed when the user acts on a soft-link
    (see gh-399). Thanks to Alistair Muldal.
  * Now ptrepack recognizes hardlinks and replicates them in the
    output (repacked) file. This saves disk space and makes
    repacked files more conformal to the original one. Closes
    gh-380.
  * New pttree script for printing HDF5 file contents as a pretty
    ASCII tree (closes gh-400). Thanks to Alistair Muldal.
  * The internal Blosc library has been downgraded to version
    1.4.4. This is in order to still allow using multiple threads
    inside Blosc, even on multithreaded applications (see gh-411,
    gh-412, gh-437 and gh-448).
  * The print_versions() function now also reports the version of
    compression libraries used by Blosc.
  * Now the setup.py tries to use the ‘-march=native’ C flag by
    default. In falls back on ‘-msse2’ if ‘-march=native’ is not
    supported by the compiler. Closes gh-379.
  * Fixed a spurious unicode comparison warning (closes gh-372 and
    gh-373).
  * Improved handling of empty string attributes. In previous
    versions of PyTables empty string were stored as scalar HDF5
    attributes having size 1 and value ‘0’ (an empty null
    terminated string). Now empty string are stored as HDF5
    attributes having zero size
  * Added a new cookbook recipe and a couple of examples for simple
    threading with PyTables.
  * The redundant utilsextension.get_indices() function has been
    eliminated (replaced by slice.indices()). Closes gh-195.
  * Allow negative indices in point selection (closes gh-360)
  * Index wasn’t being used if it claimed there were no results.
    Closes gh-351 (see also gh-353)
  * Atoms and Col types are no longer generated dynamically so now
    it is easier for IDEs and static analysis tool to handle them
    (closes gh-345)
  * The keysort functions in idx-opt.c have been cythonised using
    fused types. The perfomance is mostly unchanged, but the code
    is much more simpler now. Thanks to Andrea Bedini.
  * Small unit tests re-factoring
  Bugs fixed
  * Fixed compatibility problems with numpy 1.9 and 1.10-dev
    (closes gh-362 and gh-366)
  * Fixed compatibility with Cython >= 0.20 (closes gh-386 and
    gh-387)
  * Fixed support for unicode node names in LRU cache (only Python
    2 was affected). Closes gh-367 and gh-369.
  * Fixed support for unicode node titles (only Python 2 was
    affected). Closes gh-370 and gh-374.
  * Fixed a bug that caused the silent truncation of unicode
    attributes containing the ‘0’ character. Closes gh-371.
  * Fixed descr_from_dtype() to work as expected with complex
    types. Closes gh-381.
  * Fixed the tests.test_basics.ThreadingTestCase test case. Closes
    gh-359.
  * Fix incomplete results when performing the same query twice and
    exhausting the second iterator before the first. The first one
    writes incomplete results to seqcache (gh-353)
  * Fix false results potentially going to seqcache if
    tableextension.Row.update() is used during iteration (see
    gh-353)
  * Fix Column.create_csindex() when there’s NaNs
  * Fixed handling of unicode file names on windows (closes gh-389)
  * No longer not modify sys.argv at import time (closes gh-405)
  * Fixed a performance issue on NFS (closes gh-402)
  * Fixed a nasty problem affecting results of indexed queries.
    Closes gh-319 and probably gh-419 too.
  * Fixed another problem affecting results of indexed queries too.
    Closes gh-441.
  * Replaced “len(xrange(start, stop, step))” -> “len(xrange(0,
    stop - start, step))” to fix issues with large row counts with
    Python 2.x. Fixes #447.
  Other changes
  * Cython is not a hard dependency anymore (although developers
    will need it so as to generated the C extension code).
  * The number of threads used by default for numexpr and Blosc
    operation that was set to the number of available cores have
    been reduced to 2. This is a much more reasonable setting for
    not creating too much overhead.
- add python-setuptools as a new build dependency
- pass -q to %%setup to avoid spamming the build log
- rename README.txt to README.rst: changed upstream
- add new binary pttree to the package
* Thu May  8 2014 toddrme2178@gmail.com
- New version 3.1.1
  - Fixed a critical bug that caused an exception at import time.
    The error was triggered when a bug in long-double detection is detected
    in the HDF5 library (see :issue:`275`) and numpy_ does not expose
    `float96` or `float128`. Closes :issue:`344`.
  - The internal Blosc_ library has been updated to version 1.3.5.
    This fixes a false buffer overrun condition that made c-blosc to fail,
    even if the problem was not real.
- New version 3.1.0
  - New features¶
  - Now PyTables is able to save/restore the default value
    of EnumAtom types.
  - Implemented support for the H5FD_SPLIT driver.
  - New quantization filter: the filter truncates floating point
    data to a specified precision before writing to disk.
    This can significantly improve the performance of compressors.
  - Added new VLArray.get_row_size() method to VLArray for querying
    the number of atoms of a VLArray row. Closes gh-24 and gh-315.
  - The internal Blosc library has been updated to version 1.3.2.
    All new features introduced in the Blosc 1.3.x series, and in
    particular the ability to leverage different compressors within
    Blosc (see the Blosc Release Notes), are now available in
    PyTables via the blosc filter.
  - Improvements¶
  - The node caching mechanism has been completely redesigned to
    be simpler and less dependent from specific behaviours of
    the __del__ method. Now PyTables is compatible with the
    forthcoming Python 3.4. Closes gh-306.
  - PyTables no longer uses shared/cached file handlers.
    This change somewhat improves support for concurrent reading
    allowing the user to safely open the same file in different
    threads for reading (requires HDF5 >= 1.8.7). More details
    about this change can be found in the Backward incompatible
    changes section. See also gh-130, gh-129 gh-292 and gh-216.
  - PyTables is now able to detect and use external installations
    of the Blosc library (closes gh-104). If Blosc is not found in
    the system, and the user do not specify a custom installation
    directory, then it is used an internal copy of the Blosc source
    code.
  - Automatically disable extended float support if a buggy version
    of HDF5 is detected (see also Issues with H5T_NATIVE_LDOUBLE).
  - Documented an unexpected behaviour with string literals in query
    conditions on Python 3 (closes gh-265)
  - The deprecated getopt module has been dropped in favour of
    argparse in all command line utilities (close gh-251)
  - Improved the installation section of the PyTables User’s Guide.
  - instructions for installing PyTables via pip have been added.
  - added a reference to the Anaconda, Canopy and Christoph
    Gohlke suites (closes gh-291)
  - Enabled Travis-CI builds for Python 3.3
  - Tables.read_coordinates() now also works with boolean indices input.
  - Improved compatibility with numpy >= 1.8 (see gh-259)
  - The code of the benchmark programs (bench directory) has been updated.
  - Fixed some warning related to non-unicode file names
    (the Windows bytes API has been deprecated in Python 3.4)
  - Bugs fixed¶
  - Fixed detection of platforms supporting Blosc
  - Fixed a crash that occurred when one attempts to write a numpy array
    to an Atom (closes gh-209 and gh-296)
  - Prevent creation of a table with no columns.
  - Fixed a memory leak that occured when iterating over
    CArray/EArray objects.
  - Make NaN types sort to the end. Closes gh-282 and gh-313
  - Fixed selection on float columns when NaNs are present.
  - Fix computation of the buffer size for iterations on rows.
    The buffers size was overestimated resulting in a MemoryError
    in some cases. Closes gh-316. Thamks to bbudescu.
  - Better check of file open mode. Closes gh-318.
  - The Blosc filter now works correctly together with fletcher32. Closes gh-21.
  - Close the file handle before trying to delete the corresponding file.
    Fixes a test failure on Windows.
  - Use integer division for computing indices (fixes some warning on Windows)
- Use external python-blosc.  The internal one builds a bad version
  of zlib.
* Tue Oct 22 2013 toddrme2178@gmail.com
- new version 3.0.0
  * New features
  - Since this release PyTables provides full support to Python_ 3
    (closes :issue:`188`).
  - The entire code base is now more compliant with coding style guidelines
    describe in the PEP8_ (closes :issue:`103` and :issue:`224`).
    See `API changes`_ for more details.
  - Basic support for HDF5 drivers.  Now it is possible to open/create an
    HDF5 file using one of the SEC2, DIRECT, LOG, WINDOWS, STDIO or CORE
    drivers.  Users can also set the main driver parameters (closes
    :issue:`166`).
    Thanks to Michal Slonina.
  - Basic support for in-memory image files.  An HDF5 file can be set from or
    copied into a memory buffer (thanks to Michal Slonina).  This feature is
    only available if PyTables is built against HDF5 1.8.9 or newer.
    Closes :issue:`165` and :issue:`173`.
  - New :meth:`File.get_filesize` method for retrieving the HDF5 file size.
  - Implemented methods to get/set the user block size in a HDF5 file
    (closes :issue:`123`)
  - Improved support for PyInstaller_.  Now it is easier to pack frozen
    applications that use the PyTables package (closes: :issue:`177`).
    Thanks to Stuart Mentzer and Christoph Gohlke.
  - All read methods now have an optional *out* argument that allows to pass a
    pre-allocated array to store data (closes :issue:`192`)
  - Added support for the floating point data types with extended precision
    (Float96, Float128, Complex192 and Complex256).  This feature is only
    available if numpy_ provides it as well.
    Closes :issue:`51` and :issue:`214`.  Many thanks to Andrea Bedini.
  - Consistent ``create_xxx()`` signatures.  Now it is possible to create all
    data sets :class:`Array`, :class:`CArray`, :class:`EArray`,
    :class:`VLArray`, and :class:`Table` from existing Python objects (closes
    :issue:`61` and :issue:`249`).  See also the `API changes`_ section.
  - Complete rewrite of the :mod:`nodes.filenode` module. Now it is fully
    compliant with the interfaces defined in the standard :mod:`io` module.
    Only non-buffered binary I/O is supported currently.
    See also the `API changes`_ section.  Closes :issue:`244`.
  - New :program:`pt2to3` tool is provided to help users to port their
    applications to the new API (see `API changes`_ section).
  * Improvements
  - Improved runtime checks on dynamic loading of libraries: meaningful error
    messages are generated in case of failure.
    Also, now PyTables no more alters the system PATH.
    Closes :issue:`178` and :issue:`179` (thanks to Christoph Gohlke).
  - Improved list of search paths for libraries as suggested by Nicholaus
    Halecky (see :issue:`219`).
  - Removed deprecated Cython_ include (.pxi) files. Contents of
    :file:`convtypetables.pxi` have been moved in :file:`utilsextension.pyx`.
    Closes :issue:`217`.
  - The internal Blosc_ library has been upgraded to version 1.2.3.
  - Pre-load the bzip2_ library on windows (closes :issue:`205`)
  - The :meth:`File.get_node` method now accepts unicode paths
    (closes :issue:`203`)
  - Improved compatibility with Cython_ 0.19 (see :issue:`220` and
    :issue:`221`)
  - Improved compatibility with numexpr_ 2.1 (see also :issue:`199` and
    :issue:`241`)
  - Improved compatibility with development versions of numpy_
    (see :issue:`193`)
  - Packaging: since this release the standard tar-ball package no more includes
    the PDF version of the "PyTables User Guide", so it is a little bit smaller
    now.  The complete and pre-build version of the documentation both in HTML
    and PDF format is available on the file `download area`_ on SourceForge.net.
    Closes: :issue:`172`.
  - Now PyTables also uses `Travis-CI`_ as continuous integration service.
    All branches and all pull requests are automatically tested with different
    Python_ versions.  Closes :issue:`212`.
  * Other changes
  - PyTables now requires Python 2.6 or newer.
  - Minimum supported version of Numexpr_ is now 2.0.
  * API changes
    The entire PyTables API as been made more PEP8_ compliant (see :issue:`224`).
    This means that many methods, attributes, module global variables and also
    keyword parameters have been renamed to be compliant with PEP8_ style
    guidelines (e.g. the ``tables.hdf5Version`` constant has been renamed into
    ``tables.hdf5_version``).
    We made the best effort to maintain compatibility to the old API for existing
    applications.  In most cases, the old 2.x API is still available and usable
    even if it is now deprecated (see the Deprecations_ section).
    The only important backwards incompatible API changes are for names of
    function/methods arguments.  All uses of keyword arguments should be
    checked and fixed to use the new naming convention.
    The new :program:`pt2to3` tool can be used to port PyTables based applications
    to the new API.
    Many deprecated features and support for obsolete modules has been dropped:
  - The deprecated :data:`is_pro` module constant has been removed
  - The nra module and support for the obsolete numarray module has been removed.
    The *numarray* flavor is no more supported as well (closes :issue:`107`).
  - Support for the obsolete Numeric module has been removed.
    The *numeric* flavor is no longer available (closes :issue:`108`).
  - The tables.netcdf3 module has been removed (closes :issue:`68`).
  - The deprecated :exc:`exceptions.Incompat16Warning` exception has been
    removed
  - The :meth:`File.create_external_link` method no longer has a keyword
    parameter named *warn16incompat*.  It was deprecated in PyTables 2.4.
  - The :meth:`File.create_array`, :meth:`File.create_carray`,
    :meth:`File.create_earray`, :meth:`File.create_vlarray`, and
    :meth:`File.create_table` methods of the :class:`File` objects gained a
    new (optional) keyword argument named ``obj``.  It can be used to initialize
    the newly created dataset with an existing Python object, though normally
    these are numpy_ arrays.
    The *atom*/*descriptor* and *shape* parameters are now optional if the
  * obj* argument is provided.
  - The :mod:`nodes.filenode` has been completely rewritten to be fully
    compliant with the interfaces defined in the :mod:`io` module.
    The FileNode classes currently implemented are intended for binary I/O.
    Main changes:
  * the FileNode base class is no more available,
  * the new version of :class:`nodes.filenode.ROFileNode` and
    :class:`nodes.filenode.RAFileNode` objects no more expose the *offset*
    attribute (the *seek* and *tell* methods can be used instead),
  * the *lineSeparator* property is no more available end the ``\n``
    character is always used as line separator.
  - The `__version__` module constants has been removed from almost all the
    modules (it was not used after the switch to Git).  Of course the package
    level constant (:data:`tables.__version__`) still remains.
    Closes :issue:`112`.
  - The :func:`lrange` has been dropped in favor of xrange (:issue:`181`)
  - The :data:`parameters.MAX_THREADS` configuration parameter has been dropped
    in favor of :data:`parameters.MAX_BLOSC_THREADS` and
    :data:`parameters.MAX_NUMEXPR_THREADS` (closes :issue:`147`).
  - The :func:`conditions.compile_condition` function no more has a *copycols*
    argument, it was no more necessary since Numexpr_ 1.3.1.
    Closes :issue:`117`.
  - The *expectedsizeinMB* parameter of the :meth:`File.create_vlarray` and of
    the :meth:`VLArrsy.__init__` methods has been replaced by *expectedrows*.
    See also (:issue:`35`).
  - The :meth:`Table.whereAppend` method has been renamed into
    :meth:`Table.append_where` (closes :issue:`248`).
  * Other possibly incompatible changes
  - All methods of the :class:`Table` class that take *start*, *stop* and
  * step* parameters (including :meth:`Table.read`, :meth:`Table.where`,
    :meth:`Table.iterrows`, etc) have been redesigned to have a consistent
    behaviour.  The meaning of the *start*, *stop* and *step* and their default
    values now always work exactly like in the standard :class:`slice` objects.
    Closes :issue:`44` and :issue:`255`.
  - Unicode attributes are not stored in the HDF5 file as pickled string.
    They are now saved on the HDF5 file as UTF-8 encoded strings.
  - System attributes are now stored in the HDF5 file using the character set
    that reflects the native string behaviour: ASCII for Python 2 and UTF8 for
    Python 3.  In any case, system attributes are represented as Python string.
  - The :meth:`iterrows` method of :class:`*Array` and :class:`Table` as well
    as the :meth:`Table.itersorted` now behave like functions in the standard
    :mod:`itertools` module.
    If the *start* parameter is provided and *stop* is None then the
    array/table is iterated from *start* to the last line.
    In PyTables < 3.0 only one element was returned.
  * Deprecations
  - As described in `API changes`_, all functions, methods and attribute names
    that was not compliant with the PEP8_ guidelines have been changed.
    Old names are still available but they are deprecated.
  - The use of upper-case keyword arguments in the :func:`open_file` function
    and the :class:`File` class initializer is now deprecated.  All parameters
    defined in the :file:`tables/parameters.py` module can still be passed as
    keyword argument to the :func:`open_file` function just using a lower-case
    version of the parameter name.
* Tue Jul 31 2012 toddrme2178@gmail.com
- new version 2.4.0
* Thu Mar  8 2012 saschpe@suse.de
- Spec file cleanup
- Only ship HTML docs, not the doc sources
* Sat Feb 25 2012 scorot@free.fr
- fix build for SLE-11
* Fri Jan  6 2012 toddrme2178@gmail.com
- Clean up spec file
- Fix .changes file
- Update manual
- Removed seperate manual from the sources since it is included in the tarball
* Sun Nov 20 2011 werner.ho@gmx.de
- new version 2.3.1
* Sun May 29 2011 werner@linux-xl08.site
- fixed hdf5 package change
* Sun Sep 19 2010 werner.ho@gmx.de
- new version 2.2 with numexpr support
* Sat Oct 10 2009 werner.ho@gmx.de
- new version 2.1.2
* Wed Apr 29 2009 werner.ho@gmx.de
- new version 2.1.1
* Sun Dec 21 2008 werner.ho@gmx.de
- new version 2.1
* Sun Dec 21 2008 werner.ho@gmx.de
- new version 2.1
* Fri Dec 19 2008 werner.ho@gmx.de
- new version 2.1rc2
* Tue Dec 16 2008 werner.ho@gmx.de
- need numpy-devel now
* Sun Jul 27 2008 werner.ho@gmx.de
- new version 2.0.4
* Mon Mar 24 2008 werner.ho@gmx.de
- new version 2.0.3
* Mon Nov 26 2007 werner.ho@gmx.de
- new version 2.0.2
* Sat Sep  8 2007 werner.ho@gmx.de
- new version 2.0
* Tue May 29 2007 werner.ho@gmx.de
- new version 2.0rc2
* Thu May 24 2007 werner.ho@gmx.de
- initial spec file based on a draft provided by
  Felix Richter <felix.richter2@uni-rostock.de>
